@@ -5,12 +5,13 @@
 
 import unittest
 import numpy as np
-from control.statesp import StateSpace, _convertToStateSpace
-from control.xferfcn import TransferFunction, _convertToTransferFunction
+from control.statesp import StateSpace, _convertToStateSpace, rss
+from control.xferfcn import TransferFunction, _convert_to_transfer_function, ss2tf
 from control.lti import evalfr
 from control.exception import slycot_check
 # from control.lti import isdtime
 
+
 class TestXferFcn(unittest.TestCase):
     """These are tests for functionality and correct reporting of the transfer
     function class.  Throughout these tests, we will give different input
@@ -19,58 +20,51 @@ class TestXferFcn(unittest.TestCase):
 
     # Tests for raising exceptions.
 
-    def testBadInputType(self):
+    def test_constructor_bad_input_type(self):
         """Give the constructor invalid input types."""
 
-        self.assertRaises(TypeError, TransferFunction, [[0., 1.], [2., 3.]],
-            [[5., 2.], [3., 0.]])
+        self.assertRaises(TypeError, TransferFunction, [[0., 1.], [2., 3.]], [[5., 2.], [3., 0.]])
 
-    def testInconsistentDimension(self):
+    def test_constructor_inconsistent_dimension(self):
         """Give the constructor a numerator and denominator of different
         sizes."""
 
+        self.assertRaises(ValueError, TransferFunction, [[[1.]]], [[[1.], [2., 3.]]])
+        self.assertRaises(ValueError, TransferFunction, [[[1.]]], [[[1.]], [[2., 3.]]])
         self.assertRaises(ValueError, TransferFunction, [[[1.]]],
-            [[[1.], [2., 3.]]])
-        self.assertRaises(ValueError, TransferFunction, [[[1.]]],
-            [[[1.]], [[2., 3.]]])
-        self.assertRaises(ValueError, TransferFunction, [[[1.]]],
-            [[[1.], [1., 2.]], [[5., 2.], [2., 3.]]])
+                          [[[1.], [1., 2.]], [[5., 2.], [2., 3.]]])
 
-    def testInconsistentColumns(self):
+    def test_constructor_inconsistent_columns(self):
         """Give the constructor inputs that do not have the same number of
         columns in each row."""
 
-        self.assertRaises(ValueError, TransferFunction, 1.,
-            [[[1.]], [[2.], [3.]]])
-        self.assertRaises(ValueError, TransferFunction, [[[1.]], [[2.], [3.]]],
-            1.)
+        self.assertRaises(ValueError, TransferFunction, 1., [[[1.]], [[2.], [3.]]])
+        self.assertRaises(ValueError, TransferFunction, [[[1.]], [[2.], [3.]]], 1.)
 
-    def testZeroDenominator(self):
+    def test_constructor_zero_denominator(self):
         """Give the constructor a transfer function with a zero denominator."""
 
         self.assertRaises(ValueError, TransferFunction, 1., 0.)
         self.assertRaises(ValueError, TransferFunction,
-            [[[1.], [2., 3.]], [[-1., 4.], [3., 2.]]],
-            [[[1., 0.], [0.]], [[0., 0.], [2.]]])
+                          [[[1.], [2., 3.]], [[-1., 4.], [3., 2.]]],
+                          [[[1., 0.], [0.]], [[0., 0.], [2.]]])
 
-    def testAddInconsistentDimension(self):
+    def test_add_inconsistent_dimension(self):
         """Add two transfer function matrices of different sizes."""
 
         sys1 = TransferFunction([[[1., 2.]]], [[[4., 5.]]])
-        sys2 = TransferFunction([[[4., 3.]], [[1., 2.]]],
-            [[[1., 6.]], [[2., 4.]]])
+        sys2 = TransferFunction([[[4., 3.]], [[1., 2.]]], [[[1., 6.]], [[2., 4.]]])
         self.assertRaises(ValueError, sys1.__add__, sys2)
         self.assertRaises(ValueError, sys1.__sub__, sys2)
         self.assertRaises(ValueError, sys1.__radd__, sys2)
         self.assertRaises(ValueError, sys1.__rsub__, sys2)
 
-    def testMulInconsistentDimension(self):
+    def test_mul_inconsistent_dimension(self):
         """Multiply two transfer function matrices of incompatible sizes."""
 
         sys1 = TransferFunction([[[1., 2.], [4., 5.]], [[2., 5.], [4., 3.]]],
-            [[[6., 2.], [4., 1.]], [[6., 7.], [2., 4.]]])
-        sys2 = TransferFunction([[[1.]], [[2.]], [[3.]]],
-            [[[4.]], [[5.]], [[6.]]])
+                                [[[6., 2.], [4., 1.]], [[6., 7.], [2., 4.]]])
+        sys2 = TransferFunction([[[1.]], [[2.]], [[3.]]], [[[4.]], [[5.]], [[6.]]])
         self.assertRaises(ValueError, sys1.__mul__, sys2)
         self.assertRaises(ValueError, sys2.__mul__, sys1)
         self.assertRaises(ValueError, sys1.__rmul__, sys2)
@@ -78,7 +72,7 @@ class TestXferFcn(unittest.TestCase):
 
     # Tests for TransferFunction._truncatecoeff
 
-    def testTruncateCoeff1(self):
+    def test_truncate_coefficients_non_null_numerator(self):
         """Remove extraneous zeros in polynomial representations."""
 
         sys1 = TransferFunction([0., 0., 1., 2.], [[[0., 0., 0., 3., 2., 1.]]])
@@ -86,7 +80,7 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_equal(sys1.num, [[[1., 2.]]])
         np.testing.assert_array_equal(sys1.den, [[[3., 2., 1.]]])
 
-    def testTruncateCoeff2(self):
+    def test_truncate_coefficients_null_numerator(self):
         """Remove extraneous zeros in polynomial representations."""
 
         sys1 = TransferFunction([0., 0., 0.], 1.)
@@ -96,7 +90,7 @@ class TestXferFcn(unittest.TestCase):
 
     # Tests for TransferFunction.__neg__
 
-    def testNegScalar(self):
+    def test_reverse_sign_scalar(self):
         """Negate a direct feedthrough system."""
 
         sys1 = TransferFunction(2., np.array([-3.]))
@@ -105,7 +99,7 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_equal(sys2.num, [[[-2.]]])
         np.testing.assert_array_equal(sys2.den, [[[-3.]]])
 
-    def testNegSISO(self):
+    def test_reverse_sign_siso(self):
         """Negate a SISO system."""
 
         sys1 = TransferFunction([1., 3., 5], [1., 6., 2., -1.])
@@ -114,9 +108,8 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_equal(sys2.num, [[[-1., -3., -5.]]])
         np.testing.assert_array_equal(sys2.den, [[[1., 6., 2., -1.]]])
 
-
     @unittest.skipIf(not slycot_check(), "slycot not installed")
-    def testNegMIMO(self):
+    def test_reverse_sign_mimo(self):
         """Negate a MIMO system."""
 
         num1 = [[[1., 2.], [0., 3.], [2., -1.]],
@@ -137,7 +130,7 @@ class TestXferFcn(unittest.TestCase):
 
     # Tests for TransferFunction.__add__
 
-    def testAddScalar(self):
+    def test_add_scalar(self):
         """Add two direct feedthrough systems."""
 
         sys1 = TransferFunction(1., [[[1.]]])
@@ -147,7 +140,7 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_equal(sys3.num, 3.)
         np.testing.assert_array_equal(sys3.den, 1.)
 
-    def testAddSISO(self):
+    def test_add_siso(self):
         """Add two SISO systems."""
 
         sys1 = TransferFunction([1., 3., 5], [1., 6., 2., -1])
@@ -159,7 +152,7 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_equal(sys3.den, [[[1., 6., 1., -7., -2., 1.]]])
 
     @unittest.skipIf(not slycot_check(), "slycot not installed")
-    def testAddMIMO(self):
+    def test_add_mimo(self):
         """Add two MIMO systems."""
 
         num1 = [[[1., 2.], [0., 3.], [2., -1.]],
@@ -186,8 +179,8 @@ class TestXferFcn(unittest.TestCase):
 
     # Tests for TransferFunction.__sub__
 
-    def testSubScalar(self):
-        """Add two direct feedthrough systems."""
+    def test_subtract_scalar(self):
+        """Subtract two direct feedthrough systems."""
 
         sys1 = TransferFunction(1., [[[1.]]])
         sys2 = TransferFunction(np.array([2.]), [1.])
@@ -196,8 +189,8 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_equal(sys3.num, -1.)
         np.testing.assert_array_equal(sys3.den, 1.)
 
-    def testSubSISO(self):
-        """Add two SISO systems."""
+    def test_subtract_siso(self):
+        """Subtract two SISO systems."""
 
         sys1 = TransferFunction([1., 3., 5], [1., 6., 2., -1])
         sys2 = TransferFunction([[np.array([-1., 3.])]], [[[1., 0., -1.]]])
@@ -210,8 +203,8 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_equal(sys4.den, [[[1., 6., 1., -7., -2., 1.]]])
 
     @unittest.skipIf(not slycot_check(), "slycot not installed")
-    def testSubMIMO(self):
-        """Add two MIMO systems."""
+    def test_subtract_mimo(self):
+        """Subtract two MIMO systems."""
 
         num1 = [[[1., 2.], [0., 3.], [2., -1.]],
                 [[1.], [4., 0.], [1., -4., 3.]]]
@@ -237,7 +230,7 @@ class TestXferFcn(unittest.TestCase):
 
     # Tests for TransferFunction.__mul__
 
-    def testMulScalar(self):
+    def test_multiply_scalar(self):
         """Multiply two direct feedthrough systems."""
 
         sys1 = TransferFunction(2., [1.])
@@ -250,7 +243,7 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_equal(sys3.num, sys4.num)
         np.testing.assert_array_equal(sys3.den, sys4.den)
 
-    def testMulSISO(self):
+    def test_multiply_siso(self):
         """Multiply two SISO systems."""
 
         sys1 = TransferFunction([1., 3., 5], [1., 6., 2., -1])
@@ -264,7 +257,7 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_equal(sys3.den, sys4.den)
 
     @unittest.skipIf(not slycot_check(), "slycot not installed")
-    def testMulMIMO(self):
+    def test_multiply_mimo(self):
         """Multiply two MIMO systems."""
 
         num1 = [[[1., 2.], [0., 3.], [2., -1.]],
@@ -280,7 +273,7 @@ class TestXferFcn(unittest.TestCase):
         num3 = [[[-24., 52., -14., 245., -490., -115., 467., -95., -56., 12.,
                   0., 0., 0.]],
                 [[24., -132., 138., 345., -768., -106., 510., 41., -79., -69.,
-                -23., 17., 6., 0.]]]
+                 -23., 17., 6., 0.]]]
         den3 = [[[48., -92., -84., 183., 44., -97., -2., 12., 0., 0., 0., 0.,
                   0., 0.]],
                 [[-48., 60., 84., -81., -45., 21., 9., 0., 0., 0., 0., 0., 0.]]]
@@ -296,7 +289,7 @@ class TestXferFcn(unittest.TestCase):
 
     # Tests for TransferFunction.__div__
 
-    def testDivScalar(self):
+    def test_divide_scalar(self):
         """Divide two direct feedthrough systems."""
 
         sys1 = TransferFunction(np.array([3.]), -4.)
@@ -306,7 +299,7 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_equal(sys3.num, [[[6.]]])
         np.testing.assert_array_equal(sys3.den, [[[-20.]]])
 
-    def testDivSISO(self):
+    def test_divide_siso(self):
         """Divide two SISO systems."""
 
         sys1 = TransferFunction([1., 3., 5], [1., 6., 2., -1])
@@ -319,27 +312,25 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_equal(sys4.num, sys3.den)
         np.testing.assert_array_equal(sys4.den, sys3.num)
 
-    # Tests for TransferFunction.evalfr.
-    def testEvalFrSISO(self):
+    def test_evalfr_siso(self):
         """Evaluate the frequency response of a SISO system at one frequency."""
 
         sys = TransferFunction([1., 3., 5], [1., 6., 2., -1])
 
         np.testing.assert_array_almost_equal(evalfr(sys, 1j),
-            np.array([[-0.5 - 0.5j]]))
+                                             np.array([[-0.5 - 0.5j]]))
         np.testing.assert_array_almost_equal(evalfr(sys, 32j),
-            np.array([[0.00281959302585077 - 0.030628473607392j]]))
+                                             np.array([[0.00281959302585077 - 0.030628473607392j]]))
 
         # Test call version as well
         np.testing.assert_almost_equal(sys(1.j), -0.5 - 0.5j)
-        np.testing.assert_almost_equal(sys(32.j),
-            0.00281959302585077 - 0.030628473607392j)
+        np.testing.assert_almost_equal(sys(32.j), 0.00281959302585077 - 0.030628473607392j)
 
         # Test internal version (with real argument)
         np.testing.assert_array_almost_equal(sys._evalfr(1.),
-            np.array([[-0.5 - 0.5j]]))
+                                             np.array([[-0.5 - 0.5j]]))
         np.testing.assert_array_almost_equal(sys._evalfr(32.),
-            np.array([[0.00281959302585077 - 0.030628473607392j]]))
+                                             np.array([[0.00281959302585077 - 0.030628473607392j]]))
 
         # Deprecated version of the call (should generate warning)
         import warnings
@@ -350,7 +341,7 @@ class TestXferFcn(unittest.TestCase):
             assert issubclass(w[-1].category, PendingDeprecationWarning)
 
     @unittest.skipIf(not slycot_check(), "slycot not installed")
-    def testEvalFrMIMO(self):
+    def test_evalfr_mimo(self):
         """Evaluate the frequency response of a MIMO system at one frequency."""
 
         num = [[[1., 2.], [0., 3.], [2., -1.]],
@@ -367,11 +358,8 @@ class TestXferFcn(unittest.TestCase):
         # Test call version as well
         np.testing.assert_array_almost_equal(sys(2.j), resp)
 
-    # Tests for TransferFunction.freqresp.
-
-    def testFreqRespSISO(self):
-        """Evaluate the magnitude and phase of a SISO system at multiple
-        frequencies."""
+    def test_freqresp_siso(self):
+        """Evaluate the magnitude and phase of a SISO system at multiple frequencies."""
 
         sys = TransferFunction([1., 3., 5], [1., 6., 2., -1])
 
@@ -387,9 +375,8 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_almost_equal(omega, trueomega)
 
     @unittest.skipIf(not slycot_check(), "slycot not installed")
-    def testFreqRespMIMO(self):
-        """Evaluate the magnitude and phase of a MIMO system at multiple
-        frequencies."""
+    def test_freqresp_mimo(self):
+        """Evaluate the magnitude and phase of a MIMO system at multiple frequencies."""
 
         num = [[[1., 2.], [0., 3.], [2., -1.]],
                [[1.], [4., 0.], [1., -4., 3.]]]
@@ -397,45 +384,45 @@ class TestXferFcn(unittest.TestCase):
                [[3., 0., .0], [2., -1., -1.], [1.]]]
         sys = TransferFunction(num, den)
 
-        trueomega = [0.1, 1., 10.]
-        truemag = [[[0.496287094505259, 0.307147558416976, 0.0334738176210382],
+        true_omega = [0.1, 1., 10.]
+        true_mag = [[[0.496287094505259, 0.307147558416976, 0.0334738176210382],
                     [300., 3., 0.03], [1., 1., 1.]],
-                   [[33.3333333333333, 0.333333333333333, 0.00333333333333333],
+                    [[33.3333333333333, 0.333333333333333, 0.00333333333333333],
                     [0.390285696125482, 1.26491106406735, 0.198759144198533],
                     [3.01663720059274, 4.47213595499958, 104.92378186093]]]
-        truephase = [[[3.7128711165168e-4, 0.185347949995695, 1.30770596539255],
+        true_phase = [[[3.7128711165168e-4, 0.185347949995695, 1.30770596539255],
                       [-np.pi, -np.pi, -np.pi], [0., 0., 0.]],
-                     [[-np.pi, -np.pi, -np.pi],
+                      [[-np.pi, -np.pi, -np.pi],
                       [-1.66852323415362, -1.89254688119154, -1.62050658356412],
                       [-0.132989648369409, -1.1071487177940, -2.7504672066207]]]
 
-        mag, phase, omega = sys.freqresp(trueomega)
+        mag, phase, omega = sys.freqresp(true_omega)
 
-        np.testing.assert_array_almost_equal(mag, truemag)
-        np.testing.assert_array_almost_equal(phase, truephase)
-        np.testing.assert_array_equal(omega, trueomega)
+        np.testing.assert_array_almost_equal(mag, true_mag)
+        np.testing.assert_array_almost_equal(phase, true_phase)
+        np.testing.assert_array_equal(omega, true_omega)
 
     # Tests for TransferFunction.pole and TransferFunction.zero.
     
     @unittest.skipIf(not slycot_check(), "slycot not installed")
-    def testPoleMIMO(self):
+    def test_pole_mimo(self):
         """Test for correct MIMO poles."""
 
         sys = TransferFunction([[[1.], [1.]], [[1.], [1.]]],
-            [[[1., 2.], [1., 3.]], [[1., 4., 4.], [1., 9., 14.]]])
+                               [[[1., 2.], [1., 3.]], [[1., 4., 4.], [1., 9., 14.]]])
         p = sys.pole()
 
         np.testing.assert_array_almost_equal(p, [-2., -2., -7., -3., -2.])
 
     @unittest.skipIf(not slycot_check(), "slycot not installed")
-    def testDoubleCancelingPoleSiso(self):
+    def test_double_cancelling_poles_siso(self):
         
-        H = TransferFunction([1,1],[1,2,1])
+        H = TransferFunction([1, 1], [1, 2, 1])
         p = H.pole()
         np.testing.assert_array_almost_equal(p, [-1, -1])
     
     # Tests for TransferFunction.feedback
-    def testFeedbackSISO(self):
+    def test_feedback_siso(self):
         """Test for correct SISO transfer function feedback."""
 
         sys1 = TransferFunction([-1., 4.], [1., 3., 5.])
@@ -450,7 +437,7 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_equal(sys4.den, [[[1., 0., 2., -8., 8., 0.]]])
 
     @unittest.skipIf(not slycot_check(), "slycot not installed")
-    def testConvertToTransferFunction(self):
+    def test_convert_to_transfer_function(self):
         """Test for correct state space to transfer function conversion."""
 
         A = [[1., -2.], [-3., 4.]]
@@ -459,31 +446,31 @@ class TestXferFcn(unittest.TestCase):
         D = [[1., 0.], [0., 1.], [1., 0.]]
         sys = StateSpace(A, B, C, D)
 
-        tfsys = _convertToTransferFunction(sys)
+        tfsys = _convert_to_transfer_function(sys)
 
         num = [[np.array([1., -7., 10.]), np.array([-1., 10.])],
                [np.array([2., -8.]), np.array([1., -2., -8.])],
                [np.array([1., 1., -30.]), np.array([7., -22.])]]
-        den = [[np.array([1., -5., -2.]) for j in range(sys.inputs)]
-            for i in range(sys.outputs)]
+        den = [[np.array([1., -5., -2.]) for _ in range(sys.inputs)]
+               for _ in range(sys.outputs)]
 
         for i in range(sys.outputs):
             for j in range(sys.inputs):
                 np.testing.assert_array_almost_equal(tfsys.num[i][j], num[i][j])
                 np.testing.assert_array_almost_equal(tfsys.den[i][j], den[i][j])
 
-    def testMinreal(self):
+    def test_minreal(self):
         """Try the minreal function, and also test easy entry by creation
         of a Laplace variable s"""
         s = TransferFunction([1, 0], [1])
-        h = (s+1)*(s+2.00000000001)/(s+2)/(s**2+s+1)
+        h = (s + 1) * (s + 2.00000000001) / (s + 2) / (s**2 + s + 1)
         hm = h.minreal()
-        hr = (s+1)/(s**2+s+1)
+        hr = (s + 1) / (s**2 + s + 1)
         np.testing.assert_array_almost_equal(hm.num[0][0], hr.num[0][0])
         np.testing.assert_array_almost_equal(hm.den[0][0], hr.den[0][0])
         np.testing.assert_equal(hm.dt, hr.dt)
 
-    def testMinreal2(self):
+    def test_minreal_2(self):
         """This one gave a problem, due to poly([]) giving simply 1
         instead of numpy.array([1])"""
         s = TransferFunction([1, 0], [1])
@@ -497,25 +484,25 @@ class TestXferFcn(unittest.TestCase):
         np.testing.assert_array_almost_equal(H2b.den[0][0], hr.den[0][0])
         np.testing.assert_equal(H2b.dt, hr.dt)
 
-    def testMinreal3(self):
+    def test_minreal_3(self):
         """Regression test for minreal of tf([1,1],[1,1])"""
         g = TransferFunction([1,1],[1,1]).minreal()
         np.testing.assert_array_almost_equal(1.0, g.num[0][0])
         np.testing.assert_array_almost_equal(1.0, g.den[0][0])
         np.testing.assert_equal(None, g.dt)
 
-    def testMinreal4(self):
+    def test_minreal_4(self):
         """Check minreal on discrete TFs."""
         T = 0.01
         z = TransferFunction([1, 0], [1], T)
-        h = (z-1.00000000001)*(z+1.0000000001)/((z**2-1))
+        h = (z - 1.00000000001) * (z + 1.0000000001) / (z**2 - 1)
         hm = h.minreal()
         hr = TransferFunction([1], [1], T)
         np.testing.assert_array_almost_equal(hm.num[0][0], hr.num[0][0])
         np.testing.assert_equal(hr.dt, hm.dt)
 
     @unittest.skipIf(not slycot_check(), "slycot not installed")
-    def testMIMO(self):
+    def test_state_space_conversion_mimo(self):
         """Test conversion of a single input, two-output state-space
         system against the same TF"""
         s = TransferFunction([1, 0], [1])
@@ -530,13 +517,33 @@ class TestXferFcn(unittest.TestCase):
         H = TransferFunction([[h.num[0][0]], [(h*s).num[0][0]]],
                              [[h.den[0][0]], [h.den[0][0]]])
         sys = _convertToStateSpace(H)
-        H2 = _convertToTransferFunction(sys)
+        H2 = _convert_to_transfer_function(sys)
         np.testing.assert_array_almost_equal(H.num[0][0], H2.num[0][0])
         np.testing.assert_array_almost_equal(H.den[0][0], H2.den[0][0])
         np.testing.assert_array_almost_equal(H.num[1][0], H2.num[1][0])
         np.testing.assert_array_almost_equal(H.den[1][0], H2.den[1][0])
 
-    def testMatrixMult(self):
+    @unittest.skipIf(not slycot_check(), "slycot not installed")
+    def test_indexing(self):
+        tm = ss2tf(rss(5, 3, 3))
+
+        # scalar indexing
+        sys01 = tm[0, 1]
+        np.testing.assert_array_almost_equal(sys01.num[0][0], tm.num[0][1])
+        np.testing.assert_array_almost_equal(sys01.den[0][0], tm.den[0][1])
+
+        # slice indexing
+        sys = tm[:2, 1:3]
+        np.testing.assert_array_almost_equal(sys.num[0][0], tm.num[0][1])
+        np.testing.assert_array_almost_equal(sys.den[0][0], tm.den[0][1])
+        np.testing.assert_array_almost_equal(sys.num[0][1], tm.num[0][2])
+        np.testing.assert_array_almost_equal(sys.den[0][1], tm.den[0][2])
+        np.testing.assert_array_almost_equal(sys.num[1][0], tm.num[1][1])
+        np.testing.assert_array_almost_equal(sys.den[1][0], tm.den[1][1])
+        np.testing.assert_array_almost_equal(sys.num[1][1], tm.num[1][2])
+        np.testing.assert_array_almost_equal(sys.den[1][1], tm.den[1][2])
+
+    def test_matrix_multiply(self):
         """MIMO transfer functions should be multiplyable by constant
         matrices"""
         s = TransferFunction([1, 0], [1])
@@ -593,9 +600,20 @@ class TestXferFcn(unittest.TestCase):
         sys = TransferFunction([1,-1], [1], True)
         np.testing.assert_equal(sys.dcgain(), 0)
 
+    def test_ss2tf(self):
+        A = np.array([[-4, -1], [-1, -4]])
+        B = np.array([[1], [3]])
+        C = np.array([[3, 1]])
+        D = 0
+        sys = ss2tf(A, B, C, D)
+        true_sys = TransferFunction([6., 14.], [1., 8., 15.])
+        np.testing.assert_almost_equal(sys.num, true_sys.num)
+        np.testing.assert_almost_equal(sys.den, true_sys.den)
+
 
 def suite():
     return unittest.TestLoader().loadTestsFromTestCase(TestXferFcn)
 
+
 if __name__ == "__main__":
     unittest.main()
